/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

#ifndef _CommonController_H__
#define _CommonController_H__


#include "controllers/Controller.h"
#include "worldentities/ControllableEntity.h"
#include "worldentities/pawns/Pawn.h"

#include "tools/Timer.h"
#include "tools/interfaces/Tickable.h"
#include <limits>
#include "worldentities/Actionpoint.h"

namespace orxonox
{
    class _OrxonoxExport CommonController : public Controller, public Tickable
    {

        public:
            static const float hardcoded_projectile_speed = 750;
            static const float ACTION_INTERVAL = 1.0f;

            CommonController(Context* context);
            virtual ~CommonController();

            virtual void tick(float dt); 

            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
                


            virtual bool setWingman(CommonController* wingman);
            virtual bool hasWingman();        


            float randomInRange(float a, float b);
            static float distance(ControllableEntity* entity1, ControllableEntity* entity2);
            static bool sameTeam (ControllableEntity* entity1, ControllableEntity* entity2, Gametype* gt);
            static bool isLooking( ControllableEntity* entityThatLooks, ControllableEntity* entityBeingLookedAt, float angle ) ;
            static std::string getName( Pawn* entity ) ;

        protected:
           
            bool bFirstTick_; 
            
           
    };
}

#endif /* _CommonController_H__ */
